@@ -93,7 +93,7 @@ static void gmtk_media_tracker_init(GmtkMediaTracker * tracker)
 #else
     GTK_WIDGET_UNSET_FLAGS(tracker->scale, GTK_CAN_FOCUS);
 #endif
-    gtk_widget_set_size_request(tracker->scale, 200, -1);
+    gtk_widget_set_size_request(tracker->scale, -1, -1);
     gtk_widget_show(tracker->scale);
     gtk_box_pack_start(GTK_BOX(tracker), GTK_WIDGET(tracker->scale), TRUE, TRUE, 0);
     gtk_widget_set_sensitive(tracker->scale, FALSE);
@@ -205,7 +205,7 @@ static gboolean gmtk_media_tracker_motion_notify(GtkWidget * tracker, GdkEventMo
         gtk_range_set_value(GTK_RANGE(GMTK_MEDIA_TRACKER(tracker)->scale), position);
         g_signal_emit_by_name(tracker, "value-changed", (gint) (100 * position));
         difference = (GMTK_MEDIA_TRACKER(tracker)->length * position) - GMTK_MEDIA_TRACKER(tracker)->position;
-        gm_log(FALSE, G_LOG_LEVEL_MESSAGE, "difference = %lf", difference);
+        gm_log(FALSE, G_LOG_LEVEL_DEBUG, "difference = %lf", difference);
         //if (ABS(difference) > 15)
         //    g_signal_emit_by_name(tracker, "difference-changed", difference);
 
